using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using Ventuz.OSC;


//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// This application demonstrates the receiving of OCS data sent from a Ventuz machine.
//
// Remember always to link to the latest version of the Ventuz.OSC.dll!
// The DLL can be found in the Ventuz installation folder.
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


namespace OSC_Remoting
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		private System.Windows.Forms.ProgressBar progressBar1;
		private System.Windows.Forms.ProgressBar progressBar2;
		private System.Windows.Forms.ProgressBar progressBar3;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Timers.Timer timer1;

		UdpReader reader;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			// read from all interfaces
			reader = new UdpReader( 7000 ); 
			// read from all interfaces and a multicast group
			//reader = new UdpReader( 7000, "230.1.1.1" ); 
			
			this.progressBar1.Value = 20;
			this.progressBar2.Value = 50;
			this.progressBar3.Value = 90;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.progressBar1 = new System.Windows.Forms.ProgressBar();
			this.label1 = new System.Windows.Forms.Label();
			this.progressBar3 = new System.Windows.Forms.ProgressBar();
			this.progressBar2 = new System.Windows.Forms.ProgressBar();
			this.label3 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.timer1 = new System.Timers.Timer();
			((System.ComponentModel.ISupportInitialize)(this.timer1)).BeginInit();
			this.SuspendLayout();
			// 
			// progressBar1
			// 
			this.progressBar1.Location = new System.Drawing.Point(104, 40);
			this.progressBar1.Name = "progressBar1";
			this.progressBar1.Size = new System.Drawing.Size(152, 24);
			this.progressBar1.TabIndex = 0;
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(16, 44);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(64, 16);
			this.label1.TabIndex = 3;
			this.label1.Text = "Progress 1:";
			// 
			// progressBar3
			// 
			this.progressBar3.Location = new System.Drawing.Point(104, 216);
			this.progressBar3.Name = "progressBar3";
			this.progressBar3.Size = new System.Drawing.Size(152, 24);
			this.progressBar3.TabIndex = 4;
			// 
			// progressBar2
			// 
			this.progressBar2.Location = new System.Drawing.Point(104, 128);
			this.progressBar2.Name = "progressBar2";
			this.progressBar2.Size = new System.Drawing.Size(152, 24);
			this.progressBar2.TabIndex = 5;
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(16, 222);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(64, 16);
			this.label3.TabIndex = 6;
			this.label3.Text = "Progress 3:";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(16, 132);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(64, 16);
			this.label2.TabIndex = 7;
			this.label2.Text = "Progress 2:";
			// 
			// timer1
			// 
			this.timer1.Enabled = true;
			this.timer1.SynchronizingObject = this;
			this.timer1.Elapsed += new System.Timers.ElapsedEventHandler(this.timer1_Elapsed);
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(292, 266);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.progressBar2);
			this.Controls.Add(this.progressBar3);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.progressBar1);
			this.Name = "Form1";
			this.Text = "Form1";
			((System.ComponentModel.ISupportInitialize)(this.timer1)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}

		private void timer1_Elapsed(object sender, System.Timers.ElapsedEventArgs e)
		{
			if ( reader != null ) 
			{
				OscBundle bundle = reader.ReceiveBundle();
				OscBundle lastBundle = bundle;

				// always take the last bundle if there are more than one in the queue
				while ( bundle != null )
				{
					lastBundle = bundle;
					bundle = reader.ReceiveBundle();
				}

				bundle = lastBundle;

				if ( bundle != null ) 
				{
					foreach( OscElement element in bundle.Elements ) 
					{
						// check for desired OSC adress
						if ( element.Address == "/Values" )
						{
							// get elements
							object[] elements = element.Args;
							int v1 = 0;
							int v2 = 0;
							int v3 = 0;

							// convert to integer
							try
							{
								v1 = Convert.ToInt32( elements[0] );
								if ( v1 < 0 ) v1 = 0;
								if ( v1 > 10) v1 = 10;
							}
							catch {}

							try
							{
								v2 = Convert.ToInt32( elements[1] );
								if ( v2 < 0 ) v2 = 0;
								if ( v2 > 10) v2 = 10;
							}
							catch {}
							
							try
							{
								v3 = Convert.ToInt32( elements[2] );
								if ( v3 < 0 ) v3 = 0;
								if ( v3 > 10) v3 = 10;
							}
							catch {}

							// set progress bars
							this.progressBar1.Value = 10 * v1;
							this.progressBar2.Value = 10 * v2;
							this.progressBar3.Value = 10 * v3;
						}
					}
				}
			}
		}
	}
}
